/**
 * Throttles method calling
 */
export function Throttle(timeMs) {
    return function (target, propertyKey, descriptor) {
        let timeout;
        let nextCall;
        const ogMethod = descriptor.value;
        descriptor.value = function (...args) {
            const now = Date.now();
            if (nextCall === undefined || nextCall <= timeMs) {
                nextCall = now + timeMs;
                return ogMethod.apply(this, args);
            }
            else {
                const remaining = nextCall - now;
                if (timeout) {
                    clearTimeout(timeout);
                }
                timeout = window.setTimeout(() => {
                    nextCall = now + timeMs;
                    ogMethod.apply(this, args);
                }, remaining);
            }
        };
        return descriptor;
    };
}
//# sourceMappingURL=throttle.js.map